@@ -3,11 +3,11 @@ This module is used to represent the control logic data in 2-dimensional form.
 The data values are represented as colors in the graph.
 """
 
+import base64
 import seaborn as sns
 import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 import matplotlib
-import base64
 
 class ChessImageGenerator:
     "Class to create the gif"
@@ -17,7 +17,7 @@ class ChessImageGenerator:
         "Prepare the rows and columns for the graph"
         matplotlib.use('agg')
 
-        if game_data == None:
+        if game_data is None or not "white" in game_data:
             print("Doing nothing for this game")
             return
 
@@ -52,5 +52,6 @@ class ChessImageGenerator:
         anim = animation.FuncAnimation(fig, animate, interval=1000,
                                         save_count=len(gamedata_mapwhite))
         anim.save(filename + ".gif", dpi=80, writer='imagemagick')
-        fh = open(filename + ".gif", 'rb')
-        return {"bytes": base64.b64encode(fh.read()), "filename": "resources/output/" + filename + ".gif"}
+        file_handle = open(filename + ".gif", 'rb')
+        return {"bytes": base64.b64encode(file_handle.read()), "filename": "resources/output/"
+                        + filename + ".gif"}
